rai\_toolbox.optim.LinfProjectedOptim
=====================================

.. currentmodule:: rai_toolbox.optim

.. autoclass:: LinfProjectedOptim

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~LinfProjectedOptim.__init__

   
   